@@ -6,12 +6,12 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef MAILIMPORTER_FILTER_PLAIN_H
 #define MAILIMPORTER_FILTER_PLAIN_H
 
 #include "filters.h"
-namespace MailImporter {
+namespace MailImporter
+{
 /**
  *imports Plain text messages into KMail
  *@author laurence
